@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
   based on code from kopete
 
   SPDX-License-Identifier: LGPL-2.0-or-later
@@ -37,9 +37,7 @@ EmoticonTextEditSelector::EmoticonTextEditSelector(QWidget *parent)
     setMinimumSize(400, 200);
 }
 
-EmoticonTextEditSelector::~EmoticonTextEditSelector()
-{
-}
+EmoticonTextEditSelector::~EmoticonTextEditSelector() = default;
 
 void EmoticonTextEditSelector::slotItemSelected(const QString &str)
 {
