@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,15 +25,13 @@ TextToSpeechGui::TextToSpeechGui(QWidget *parent)
 
     QMenu *editMenu = menuBar()->addMenu(QStringLiteral("Edit"));
 
-    QAction *act = new QAction(i18n("Speech text"), this);
+    auto act = new QAction(i18n("Speech text"), this);
     connect(act, &QAction::triggered, this, &TextToSpeechGui::slotTextToSpeech);
     editMenu->addAction(act);
     qDebug() << " isReady ? " << KPIMTextEdit::TextToSpeech::self()->isReady();
 }
 
-TextToSpeechGui::~TextToSpeechGui()
-{
-}
+TextToSpeechGui::~TextToSpeechGui() = default;
 
 void TextToSpeechGui::slotTextToSpeech()
 {
